summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Bauer <mail@david-bauer.net>2019-11-17 22:19:44 +0100
committerBeniamino Galvani <bgalvani@redhat.com>2019-12-05 14:00:10 +0100
commit1e55eff49872d65a75b4923c2fb4d13a5f2d9bd4 (patch)
tree7ba05ea1fe4e601a9fd027b09c475bdc4984cf89
parent85c4a757ada39ccbd705ab76723511716d41aa0e (diff)
downloadNetworkManager-1e55eff49872d65a75b4923c2fb4d13a5f2d9bd4.tar.gz
supplicant: add support for OWE key management
-rw-r--r--src/supplicant/nm-supplicant-config.c7
-rw-r--r--src/supplicant/nm-supplicant-settings-verify.c2
2 files changed, 5 insertions, 4 deletions
diff --git a/src/supplicant/nm-supplicant-settings-verify.c b/src/supplicant/nm-supplicant-settings-verify.c
index bea17ede24..20287b8ca6 100644
--- a/src/supplicant/nm-supplicant-settings-verify.c
+++ b/src/supplicant/nm-supplicant-settings-verify.c
@@ -56,7 +56,7 @@ static const char *const key_mgmt_allowed[] = { "WPA-PSK", "WPA-PSK-SHA256", "FT
"WPA-EAP", "WPA-EAP-SHA256", "FT-EAP", "FT-EAP-SHA384",
"FILS-SHA256", "FILS-SHA384",
"IEEE8021X", "SAE", "FT-SAE",
- "NONE", NULL };
+ "OWE", "NONE", NULL };
static const char *const auth_alg_allowed[] = { "OPEN", "SHARED", "LEAP", NULL };
static const char *const eap_allowed[] = { "LEAP", "MD5", "TLS", "PEAP", "TTLS", "SIM",
"PSK", "FAST", "PWD", NULL };
diff --git a/src/supplicant/nm-supplicant-config.c b/src/supplicant/nm-supplicant-config.c
index dec4556d1c..8b9c0ceb40 100644
--- a/src/supplicant/nm-supplicant-config.c
+++ b/src/supplicant/nm-supplicant-config.c
@@ -867,8 +867,8 @@ nm_supplicant_config_add_setting_wireless_security (NMSupplicantConfig *self,
}
}
- /* Don't try to enable PMF on non-WPA/SAE networks */
- if (!NM_IN_STRSET (key_mgmt, "wpa-eap", "wpa-psk", "sae"))
+ /* Don't try to enable PMF on non-WPA/SAE/OWE networks */
+ if (!NM_IN_STRSET (key_mgmt, "wpa-eap", "wpa-psk", "sae", "owe"))
pmf = NM_SETTING_WIRELESS_SECURITY_PMF_DISABLE;
/* Check if we actually support PMF */
@@ -885,7 +885,8 @@ nm_supplicant_config_add_setting_wireless_security (NMSupplicantConfig *self,
/* Only WPA-specific things when using WPA */
if ( !strcmp (key_mgmt, "wpa-psk")
|| !strcmp (key_mgmt, "wpa-eap")
- || !strcmp (key_mgmt, "sae")) {
+ || !strcmp (key_mgmt, "sae")
+ || !strcmp (key_mgmt, "owe")) {
if (!ADD_STRING_LIST_VAL (self, setting, wireless_security, proto, protos, "proto", ' ', TRUE, NULL, error))
return FALSE;
if (!ADD_STRING_LIST_VAL (self, setting, wireless_security, pairwise, pairwise, "pairwise", ' ', TRUE, NULL, error))